@@ -1,37 +1,39 @@
 from __future__ import absolute_import
 
+import os
 from inspect import getsourcefile
 from os.path import abspath
 from pathlib import Path
-from typing import Union, TYPE_CHECKING
+from typing import Callable, Union, TYPE_CHECKING, Tuple, Optional
 
-from _pytest._code.code import TerminalRepr, Traceback, ExceptionInfo
+import pytest
 from _pytest import fixtures
+from _pytest._code.code import TerminalRepr, Traceback, ExceptionInfo
+from _pytest._io import TerminalWriter
 from _pytest.fixtures import FuncFixtureInfo
 from _pytest.main import Session
 from _pytest.nodes import Collector
 from _pytest.python import Module
-import py.path
-import pytest
 
+from .. import example as example_module
+from ..example import Example
 from ..example import SybilFailure
-from .. import example
 
 if TYPE_CHECKING:
     from ..sybil import Sybil
 
 PYTEST_VERSION = tuple(int(i) for i in pytest.__version__.split('.'))
 
-example_module_path = abspath(getsourcefile(example))
+example_module_path = abspath(getsourcefile(example_module))
 
 
 class SybilFailureRepr(TerminalRepr):
 
-    def __init__(self, item, message):
+    def __init__(self, item: 'SybilItem', message: str) -> None:
         self.item = item
         self.message = message
 
-    def toterminal(self, tw):
+    def toterminal(self, tw: TerminalWriter) -> None:
         tw.line()
         for line in self.message.splitlines():
             tw.line(line)
@@ -42,7 +44,7 @@ class SybilFailureRepr(TerminalRepr):
 
 class SybilItem(pytest.Item):
 
-    def __init__(self, parent, sybil, example):
+    def __init__(self, parent, sybil, example: Example) -> None:
         name = 'line:{},column:{}'.format(example.line, example.column)
         super(SybilItem, self).__init__(name, parent)
         self.example = example
@@ -58,11 +60,11 @@ class SybilItem(pytest.Item):
         self.funcargs = {}
         self._request = fixtures.FixtureRequest(self, _ispytest=True)
 
-    def reportinfo(self):
+    def reportinfo(self) -> Tuple[Union["os.PathLike[str]", str], Optional[int], str]:
         info = '%s line=%i column=%i' % (
-            self.fspath.basename, self.example.line, self.example.column
+            self.path.name, self.example.line, self.example.column
         )
-        return py.path.local(self.example.path), self.example.line, info
+        return self.example.path, self.example.line, info
 
     def getparent(self, cls):
         if cls is Module:
@@ -70,19 +72,31 @@ class SybilItem(pytest.Item):
         if cls is Session:
             return self.session
 
-    def setup(self):
+    def setup(self) -> None:
         self._request._fillfixtures()
         for name, fixture in self.funcargs.items():
             self.example.namespace[name] = fixture
 
-    def runtest(self):
+    def runtest(self) -> None:
         self.example.evaluate()
 
-    def _prunetraceback(self, excinfo):
-        tb = excinfo.traceback.cut(path=example_module_path)
-        tb = tb[1]
-        if getattr(tb, '_rawentry', None) is not None:
-            excinfo.traceback = Traceback(tb._rawentry, excinfo)
+    if PYTEST_VERSION >= (7, 4, 0):
+
+        def _traceback_filter(self, excinfo: ExceptionInfo[BaseException]) -> Traceback:
+            traceback = excinfo.traceback
+            tb = traceback.cut(path=example_module_path)
+            tb_entry = tb[1]
+            if getattr(tb_entry, '_rawentry', None) is not None:
+                traceback = Traceback(tb_entry._rawentry)
+            return traceback
+
+    else:
+
+        def _prunetraceback(self, excinfo):
+            tb = excinfo.traceback.cut(path=example_module_path)
+            tb_entry = tb[1]
+            if getattr(tb_entry, '_rawentry', None) is not None:
+                excinfo.traceback = Traceback(tb_entry._rawentry, excinfo)
 
     def repr_failure(
         self,
@@ -96,34 +110,31 @@ class SybilItem(pytest.Item):
 
 class SybilFile(pytest.File):
 
-    def __init__(self, *, sybil: 'Sybil', **kwargs):
+    def __init__(self, *, sybil: 'Sybil', **kwargs) -> None:
         super(SybilFile, self).__init__(**kwargs)
         self.sybil: 'Sybil' = sybil
 
     def collect(self):
-        self.document = self.sybil.parse(Path(self.fspath.strpath))
+        self.document = self.sybil.parse(self.path)
         for example in self.document:
             yield SybilItem.from_parent(self, sybil=self.sybil, example=example)
 
-    def setup(self):
+    def setup(self) -> None:
         if self.sybil.setup:
             self.sybil.setup(self.document.namespace)
 
-    def teardown(self):
+    def teardown(self) -> None:
         if self.sybil.teardown:
             self.sybil.teardown(self.document.namespace)
 
 
-def pytest_integration(*sybils: 'Sybil'):
+def pytest_integration(*sybils: 'Sybil') -> Callable[[Path, Collector], Optional[SybilFile]]:
 
-    def pytest_collect_file(path: py.path.local, parent: Collector):
-        fspath = path
-        path = Path(fspath.strpath)
+    def pytest_collect_file(file_path: Path, parent: Collector) -> Optional[SybilFile]:
         for sybil in sybils:
-            if sybil.should_parse(path):
-                if PYTEST_VERSION[0] >= 7:
-                    return SybilFile.from_parent(parent, path=path, sybil=sybil)
-                else:
-                    return SybilFile.from_parent(parent, fspath=fspath, sybil=sybil)
+            if sybil.should_parse(file_path):
+                result: SybilFile = SybilFile.from_parent(parent, path=file_path, sybil=sybil)
+                return result
+        return None
 
     return pytest_collect_file
